package dionarap;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JDialog;


/**
 * Klasse zum Reagieren auf die Schliessen-Buttons in den Fenstern
 * "Spielbeschreibung" und "Spielfiguren". Implementiert das Interface
 * <code>ActionListener</code>
 *  
 * @see java.awt.event.ActionListener
 * 
 * @author Thomas Merkel
 * @author Rainer Hihn
 * @version 1.4
 */
public class ListenerDialog implements ActionListener {

	/**
	 * Event-Handler fuer die Dialog-Fenster "Spielbeschreibung" und
	 * "Spielfiguren". 
	 * @param event Das <code>ActionEvent</code>, auf das reagiert werden soll
	 */
	@Override
	public void actionPerformed(ActionEvent event) {
		// Dialogfenster schlieen
		if (event.getActionCommand().equals(MenuBar.CMD_CLOSEWINDOW)) {
			this.actionCloseDialog((JButton)event.getSource());
			return;
		}
	}

	/**
	 * Schleisst einen Dialog. Anhand des <code>JButton</code>, der das Event geworfen
	 * hat, wird der <code>JDialog</code> ermittelt. Je nach Dialog-Typ wird der  
	 * Dialog zerstoert (modal) oder nur unsichtbar gemacht (nicht modal).
	 * @param source <code>JButton</code>, der das Event geworfen hat
	 */
	private void actionCloseDialog(JButton source)
	{
		JDialog dlg = (JDialog)(source.getTopLevelAncestor());
		if (dlg.isModal()) {
			dlg.dispose();
		} else {
			dlg.setVisible(false);
		}
	}
	
}
