package dionarap;

import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import de.fhwgt.dionarap.controller.DionaRapController;


/**
 * Klasse zum Reagieren auf Tastatur-Ereignisse im Hauptfenster.
 * Implementiert das Interface <code>KeyListener</code> 
 * 
 * @see java.awt.event.KeyListener
 * 
 * @author Thomas Merkel
 * @author Rainer Hihn
 * @version 1.4
 */
public class ListenerKeyboard implements KeyListener {

	/**
	 * Event-Handler fuer Tastendruecke des Hauptfensters. Reagiert auf
	 * die Tasten 1-9 des Ziffernblocks. Holt sich ueber den Absender
	 * des Ereignisses das <code>DionaRapController</code>-Objekt, dem
	 * es die Handlung des Spielers (Bewegung, Schuss) mitteilt.
	 * @param event Ereignis vom Typ <code>KeyEvent</code>, welches
	 *              die Identifizierung der gedrueckten Taste erlaubt
	 */
	@Override
	public void keyPressed(KeyEvent event) {
		Hauptfenster hf = (Hauptfenster)event.getSource();
		DionaRapController controller = hf.getController();
		
		switch (event.getKeyCode()) {
			case KeyEvent.VK_NUMPAD1:	
				controller.movePlayer(1);
				break;
			case KeyEvent.VK_NUMPAD2:	
			case KeyEvent.VK_S:	
				controller.movePlayer(2);
				break;
			case KeyEvent.VK_NUMPAD3:	
				controller.movePlayer(3);
				break;
			case KeyEvent.VK_NUMPAD4:	
			case KeyEvent.VK_A:	
				controller.movePlayer(4);
				break;
			case KeyEvent.VK_NUMPAD5:
			case KeyEvent.VK_SPACE:
				controller.shoot();
				break;
			case KeyEvent.VK_NUMPAD6:	
			case KeyEvent.VK_D:	
				controller.movePlayer(6);
				break;
			case KeyEvent.VK_NUMPAD7:	
				controller.movePlayer(7);
				break;
			case KeyEvent.VK_NUMPAD8:	
			case KeyEvent.VK_W:	
				controller.movePlayer(8);
				break;
			case KeyEvent.VK_NUMPAD9:	
				controller.movePlayer(9);
				break;
		}
	}

	@Override
	public void keyReleased(KeyEvent arg0) { }

	@Override
	public void keyTyped(KeyEvent arg0) { }

}
