package dionarap;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

/**
 * Diese Klasse realisiert die Listener fuer alle Menuepunkte im Spiel. Sie 
 * implementiert das Interface <code>ActionListener</code>
 * 
 * @see java.awt.event.ActionListener
 * @see Hauptfenster
 * @see MenuBar
 * 
 * @author Thomas Merkel
 * @author Rainer Hihn
 * @version 1.4
 */
public class ListenerMenu implements ActionListener {
	/** Verbindung zum Elternfenster, benoetigt fr Event-Verarbeitung */
	private Hauptfenster parent;


	/**
	 * Konstruktor der Klasse <code>ListenerMenu</code>
	 * @param parent Verbindung zum Elternfenster vom Typ <code>Hauptfenster</code>
	 * @see Hauptfenster
	 */
	ListenerMenu(Hauptfenster parent){
		this.parent = parent;
	}
	

	/**
	 * Event-Handler fuer das Menue. Folgende Aktionen werden hier durchgefuehrt:<br>
	 * - HTML Hilfe ein-/ausblenden<br>
	 * - Fenster mit den Spielfiguren einblenden<br>
	 * - Navigator ein-/ausblenden<br>
	 * - Icon-Thema umstellen<br>
	 * - Level umstellen und dann neues Spiel starten<br>
	 * - Umstellen des Look and Feels<br>
	 * @param event Das Ereignis, auf das reagiert werden muss
	 */
	@Override
	public void actionPerformed(ActionEvent event) {
		// Fenster mit den Spielfiguren anzeigen
		if (event.getActionCommand().equals(MenuBar.CMD_SHOWICONS)) {
			this.parent.showDescriptionWindow();
			return;
		}
		
		// Fenster mit LevelEditor anzeigen
		if (event.getActionCommand().equals(MenuBar.CMD_SHOWLEVELEDITOR)) {			
			this.parent.showLevelEditor();
			return;
		}
		
		
		// Fenster mit der Hilfe anzeigen
		if (event.getActionCommand().equals(MenuBar.CMD_SHOWHELP)) {
			this.parent.showHelpWindow();
			return;
		}

     	
		// Navigator einblenden oder ausblenden
		if (event.getActionCommand().equals(MenuBar.CMD_TOGGLENAVIGATOR)) {
			this.parent.toggleNavigator();
			return;
		}
		

		// Level neutral einrichten und neues Spiel starten
		if (event.getActionCommand().startsWith(Hauptfenster.levelPrefix)) {
			this.parent.startNewGame(event.getActionCommand().substring(Hauptfenster.levelPrefix.length()));
			return;
		}

		
		// Icon-Thema umstellen
		if (event.getActionCommand().startsWith(MenuBar.CMD_THEMEPREFIX)) {
			this.parent.setArtwork(event.getActionCommand().substring(MenuBar.CMD_THEMEPREFIX .length()));
			return;
		}
		
	
		// Look and Feel umstellen
		if (event.getActionCommand().contains("swing.")) {
			this.parent.setLookAndFeel(event.getActionCommand());
			return;
		}  
	}


}
