package dionarap;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.JWindow;

/**
 * Diese Klasse zeichnet das Navigationsfenster
 * 
 * @author Thomas Merkel
 * @author Rainer Hihn
 * @version 1.4
 */
public class Navigator extends JWindow {
	/**
	 * Interne Versionsnummer - Serialisieren fuer Applets, Klassentausch
	 */
	private static final long serialVersionUID = 8928980690535128687L;
	
	/** 
	 * Textfeld fr den Punktestand, nicht editierbar 
	 */
	JTextField tPunktestand = new JTextField();
	
	/** 
	 * Button, welcher ein neues Spiel startet. 
	 * Ist deaktiviert, so lange ein Spiel laeuft. 
	 */
	JButton bNewGame = new JButton("Neues Spiel");
	
	/**
	 * Konstruktor der <code>Navigator</code>-Klasse. Erstellt ein Fenster mit
	 * Tastatur, Punktestand und Buttom zum Starten eines neuen Spiels.
	 * 
	 * @param parent Elternfenster vom Typ <code>JFrame</code>
	 */
	public Navigator(JFrame parent) {
		super(parent);

		this.tPunktestand.setEditable(false);
		this.bNewGame.addActionListener(new ListenerNewGame());
		
		JLabel lblPunktestand = new JLabel("Puntestand:");
		lblPunktestand.setOpaque(true);
		lblPunktestand.setVisible(true);
		
		JPanel panelBottom = new JPanel();
		panelBottom.setLayout(new BorderLayout());
		panelBottom.add(lblPunktestand, BorderLayout.NORTH);
		panelBottom.add(this.tPunktestand, BorderLayout.SOUTH);
		
		JPanel rahmen = new JPanel();
		rahmen.setLayout(new BorderLayout());
		rahmen.setBorder(BorderFactory.createLineBorder(Color.red, 2));

		rahmen.add(new Tastatur(), BorderLayout.NORTH);
		rahmen.add(panelBottom);
		rahmen.add(this.bNewGame, BorderLayout.SOUTH);
		
		this.getContentPane().add(rahmen);

		this.updateLocation();
		this.pack();
	}
	
	/**
	 * Aktiviert oder deaktiviert den Button zum Starten eines neuen Spiels
	 * 
	 * @param enabled <code>true</code> = Button aktiviert, <code>false</code> = Button deaktiviert
	 */
	public void setNewGameButtonStatus(boolean enabled) {
		this.bNewGame.setEnabled(enabled);
	}

	/**
	 * Aktualisiert die Position des Fensters, platziert sich rechts vom Hauptfenster
	 */
	public void updateLocation() {
		this.setLocation((int)this.getParent().getLocation().getX() + this.getParent().getWidth() + 20, 
				         (int)this.getParent().getLocation().getY());
	}

	/**
	 * Setzt den angezeigten Punktestand
	 * 
	 * @param points Punktestand
	 */
	public void setPoints(int points) {
		this.tPunktestand.setText(Integer.toString(points));
	}
}
