package dionarap;

import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.font.TextLayout;
import java.awt.geom.Rectangle2D;

import javax.swing.ImageIcon;
import javax.swing.JPanel;

/**
 * Diese Klasse realisiert die Einbindung der Figuren durch die Draw Methoden von Graphics.
 * Sie erbt von <code>JPanel</code>.
 * 
 * @see javax.swing.JPanel
 * 
 * @author Thomas Merkel
 * @author Rainer Hihn
 * @version 1.4
 */
public class PaintGraphic extends JPanel{
	/**
	 *  Interne Versionsnummer - Serialisieren fuer Applets, Klassentausch
	 */
	private static final long serialVersionUID = 8779958318489877425L;


	/** 
	 * Untertitel des Icons  
	 */
	private String bezeichnung;
	
	
	/** Das darzustellende Icon */
	private ImageIcon icon;

	
	/**
	 * Konstruktor der Klasse MyGraphic
	 * 
	 * @param bezeichnung Beschriftung unterhalb des Icons
	 * @param icon Bild, das gezeichnet werden soll
	 */
	public PaintGraphic(String bezeichnung, ImageIcon icon)
	{
		this.bezeichnung = bezeichnung;
		this.icon = icon;
		
		this.setPreferredSize(new Dimension(60, 80));
	}
	
	/**
	 * Zeichnet das Icon und darunter die Beschriftung des Bildes. Zum
	 * Zeichnen wird die Klasse <code>Graphics2D</code> verwendet.
	 * 
	 * @param graphics Grafik, in die gezeichnet werden soll
	 */
	@Override
	protected void paintComponent(Graphics graphics)
	{
		super.paintComponent(graphics);
		// Bilder sollten vorher gebuffert werden bevor diese mit drawImage gezeichnet werden
		// -> grosse bilder
		Graphics2D graphics2d = (Graphics2D)graphics;
		graphics2d.drawImage(this.icon.getImage(), 5, 5, this);

		TextLayout layout = new TextLayout(this.bezeichnung, graphics2d.getFont(), graphics2d.getFontRenderContext()); 
		Rectangle2D rect = layout.getBounds();
		graphics2d.drawString(this.bezeichnung, 30 - (int)rect.getCenterX(), 65);		
	}
}
