package dionarap;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.GridLayout;

import javax.swing.JLabel;
import javax.swing.JPanel;

import de.fhwgt.dionarap.model.objects.AbstractPawn;
import de.fhwgt.dionarap.model.objects.Ammo;
import de.fhwgt.dionarap.model.objects.Destruction;
import de.fhwgt.dionarap.model.objects.Obstacle;
import de.fhwgt.dionarap.model.objects.Opponent;
import de.fhwgt.dionarap.model.objects.Player;
import de.fhwgt.dionarap.model.objects.Vortex;

/**
 * Zeichnet das Spielfeld
 * 
 * @author Thomas Merkel
 * @author Rainer Hihn
 * @version 1.4
*/
public class Spielfeld extends JPanel {

	/**
	 * Interne Versionsnummer - Serialisieren fuer Applets, Klassentausch
	 */
	private static final long serialVersionUID = 5715276577498012282L;
		
	/**
	 * Array mit den Feldern, 1. Index ist die Zeile, 2. Index ist die Spalte 
	 */
	private JLabel schachBrett[][];
	
	/** 
	 * Aktueller Spiel-Status 
	 */
	private GameStatus status = GameStatus.game;
	
	/**
	 * Konstruktor der Klasse <code>Spielfeld</code>. Erwartet die Gre des Grids
	 * und die Gre der Felder in Pixel.
	 * @param felderX horizontale Gre des Spielfeldes
	 * @param felderY vertikale Gre des Spielfeldes
	 */
	public Spielfeld( int felderX, int felderY ) {		
		JPanel panel = new JPanel( new GridLayout( felderX, felderY ) );
		this.add(panel);
		
		this.schachBrett = new JLabel[felderX][felderY];
				
		for( int reihe = 0; reihe < felderX; ++reihe ) {
			for( int spalte = 0; spalte < felderY; ++spalte ) {
				schachBrett[reihe][spalte] = new JLabel();
				schachBrett[reihe][spalte].setPreferredSize(new Dimension(50,50));
				
				if( reihe % 2 == 0 ) { 
					if( spalte % 2 == 0 )
						schachBrett[reihe][spalte].setBackground(Color.white);
					else
						schachBrett[reihe][spalte].setBackground(Color.black);
				} else {
					if( spalte % 2 == 0 )
						schachBrett[reihe][spalte].setBackground(Color.black);
					else
						schachBrett[reihe][spalte].setBackground(Color.white);
				}
				
				schachBrett[reihe][spalte].setOpaque(true);
				panel.add( schachBrett[reihe][spalte] );
			}
		}
	}
		
	/**
	 * Teilt dem Spielfeld einen Status mit. Wenn der aktuelle Spielfeld-Status
	 * dem Status <code>game</code> entspricht, wird der neue Status uebernommen.
	 * Diese Einschraenkung ist noetig, da auch bei einem Thema-Wechsels die
	 * Methode aufgerufen wird.
	 * 
	 * @param status Neuer Status
	 */
	public void updateStatus(GameStatus status)
	{
		if (this.status == GameStatus.game) {
			this.status = status;
		}
	}
	
	/**
	 * Platziert ein ELement auf dem Spielfeld
	 * 
	 * @param pawn Figur/Element, welches platziert werden soll
	 */
	public void setPawn(AbstractPawn pawn)
	{
		JLabel feld = this.schachBrett[pawn.getY()][pawn.getX()];
		Artwork artwork = Artwork.getTheme();
		
		if (pawn instanceof Obstacle) { 
			feld.setIcon(artwork.getObstacleIcon());
		}
		if (pawn instanceof Opponent) { 
			feld.setIcon(artwork.getOpponentIcon());
		}
		if (pawn instanceof Ammo) { 
			feld.setIcon(artwork.getAmmoIcon());
		}
		if (pawn instanceof Player) {
			if (this.status == GameStatus.gameover) {
				feld.setIcon(artwork.getGameOverIcon());
			} else if (this.status == GameStatus.gamewon) {
				feld.setIcon(artwork.getGameWonIcon());
			} else {
				Player p = (Player)pawn;
				feld.setIcon(artwork.getPlayerIcon(p.getViewDirection()));
			}
		}
		if (pawn instanceof Destruction) { 
			feld.setIcon(artwork.getDestructionIcon());
		}
		if (pawn instanceof Vortex) { 
			feld.setIcon(artwork.getVortexIcon());
		}
	}

	/**
	 * Entfernt alle ELemente auf dem Spielfeld, sollte vor dem Neuzeichnen
	 * des Spielfelds aufgerufen werden.
	 */	
	public void cleanupSpielfeld() {
		for (int y = 0; y < this.schachBrett.length; y++) {
			for (int x = 0; x < this.schachBrett[y].length; x++) {
				JLabel feld = this.schachBrett[y][x];
				feld.setIcon(null);
			}
		}
	}

}
